@@ -1,13 +1,14 @@
 #!/usr/bin/env python3
-# (c) Facebook, Inc. and its affiliates. Confidential and proprietary.
+# Copyright (c) Meta Platforms, Inc. and affiliates.
+#
+# This source code is licensed under the BSD-style license found in the
+# LICENSE file in the root directory of this source tree.
 
 from hydra.core.config_store import ConfigStore
 
 from .base_channel import FLChannelConfig
 from .half_precision_channel import HalfPrecisionChannelConfig
-from .product_quantization_channel import ProductQuantizationChannelConfig
 from .scalar_quantization_channel import ScalarQuantizationChannelConfig
-from .sketch_channel import SketchChannelConfig
 from .sparse_mask_channel import SparseMaskChannelConfig
 
 ConfigStore.instance().store(
@@ -22,12 +23,6 @@ ConfigStore.instance().store(
     group="channel",
 )
 
-ConfigStore.instance().store(
-    name="base_sketch_channel",
-    node=SketchChannelConfig,
-    group="channel",
-)
-
 ConfigStore.instance().store(
     name="base_half_precision_channel",
     node=HalfPrecisionChannelConfig,
@@ -39,9 +34,3 @@ ConfigStore.instance().store(
     node=ScalarQuantizationChannelConfig,
     group="channel",
 )
-
-ConfigStore.instance().store(
-    name="base_product_quantization_channel",
-    node=ProductQuantizationChannelConfig,
-    group="channel",
-)
